SqliteDatabase

Struct SqliteDatabase 

pub struct SqliteDatabase { /* private fields */ }
Available on crate feature sqlite only.
SQLite database connection pool

Implementations

Source

impl SqliteDatabase

pub fn new(config: &DatabaseConfig) -> Result<Self, CommerceError>

Create a new SQLite database connection

pub fn in_memory() -> Result<Self, CommerceError>

Create an in-memory database (useful for testing)

pub fn conn( &self, ) -> Result<PooledConnection<SqliteConnectionManager>, CommerceError>

Get a connection from the pool

pub fn health_check(&self) -> Result<DbHealthStatus, CommerceError>

Run a health check: verify DB connectivity, return pool and storage stats.

pub fn shutdown(&self) -> Result<(), CommerceError>

Graceful shutdown: checkpoint WAL and optimize before closing.

Call this before dropping the database to ensure all WAL data is flushed to the main database file. Safe to call multiple times.

pub fn orders(&self) -> SqliteOrderRepository

Get order repository

pub fn inventory(&self) -> SqliteInventoryRepository

Get inventory repository

pub fn customers(&self) -> SqliteCustomerRepository

Get customer repository

pub fn products(&self) -> SqliteProductRepository

Get product repository

pub fn custom_objects(&self) -> SqliteCustomObjectRepository

Get custom objects repository (custom states / metaobjects)

pub fn returns(&self) -> SqliteReturnRepository

Get return repository

pub fn bom(&self) -> SqliteBomRepository

Get BOM (Bill of Materials) repository

pub fn work_orders(&self) -> SqliteWorkOrderRepository

Get work order repository

pub fn shipments(&self) -> SqliteShipmentRepository

Get shipment repository

pub fn payments(&self) -> SqlitePaymentRepository

Get payment repository

pub fn warranties(&self) -> SqliteWarrantyRepository

Get warranty repository

pub fn purchase_orders(&self) -> SqlitePurchaseOrderRepository

Get purchase order repository

pub fn invoices(&self) -> SqliteInvoiceRepository

Get invoice repository

pub fn carts(&self) -> SqliteCartRepository

Get cart repository

pub fn analytics(&self) -> SqliteAnalyticsRepository

Get analytics repository

pub fn currency(&self) -> SqliteCurrencyRepository

Get currency repository

pub fn tax(&self) -> SqliteTaxRepository

Get tax repository

pub fn promotions(&self) -> SqlitePromotionRepository

Get promotions repository

pub fn subscriptions(&self) -> SqliteSubscriptionRepository

Get subscriptions repository

pub fn quality(&self) -> SqliteQualityRepository

Get quality repository

pub fn lots(&self) -> SqliteLotRepository

Get lots repository

pub fn serials(&self) -> SqliteSerialRepository

Get serials repository

pub fn warehouse(&self) -> SqliteWarehouseRepository

Get warehouse repository

pub fn receiving(&self) -> SqliteReceivingRepository

Get receiving repository

pub fn fulfillment(&self) -> SqliteFulfillmentRepository

Get fulfillment repository

pub fn accounts_payable(&self) -> SqliteAccountsPayableRepository

Get accounts payable repository

pub fn cost_accounting(&self) -> SqliteCostAccountingRepository

Get cost accounting repository

pub fn credit(&self) -> SqliteCreditRepository

Get credit repository

pub fn backorder(&self) -> SqliteBackorderRepository

Get backorder repository

pub fn accounts_receivable(&self) -> SqliteAccountsReceivableRepository

Get accounts receivable repository

pub fn general_ledger(&self) -> SqliteGeneralLedgerRepository

Get general ledger repository

pub fn x402_payment_intents(&self) -> SqliteX402PaymentIntentRepository

Get x402 payment intent repository

pub fn x402_credits(&self) -> SqliteX402CreditRepository

Get x402 credit ledger repository

pub fn a2a_quotes(&self) -> SqliteA2ARepository

Get A2A quote/purchase repository

pub fn a2a_purchases(&self) -> SqliteA2ARepository

Get A2A quote/purchase repository

pub fn agent_cards(&self) -> SqliteAgentCardRepository

Get agent card repository

pub fn agent_identities(&self) -> SqliteAgentIdentityRepository

Get agent identity repository (ERC-8004)

pub fn agent_reputation(&self) -> SqliteAgentReputationRepository

Get agent reputation repository (ERC-8004)

pub fn agent_validation(&self) -> SqliteAgentValidationRepository

Get agent validation repository (ERC-8004)

pub fn gift_cards(&self) -> SqliteGiftCardRepository

Get gift card repository

pub fn store_credits(&self) -> SqliteStoreCreditRepository

Get store credit repository

pub fn segments(&self) -> SqliteSegmentRepository

Get customer segment repository

pub fn shipping_zones(&self) -> SqliteShippingZoneRepository

Get shipping zone repository

pub fn channels(&self) -> SqliteChannelRepository

Get channel repository

pub fn companies(&self) -> SqliteCompanyRepository

Get company (B2B account) repository

pub fn transfer_orders(&self) -> SqliteTransferOrderRepository

Get transfer order repository

pub fn units_of_measure(&self) -> SqliteUnitOfMeasureRepository

Get units-of-measure repository

pub fn production_batches(&self) -> SqliteProductionBatchRepository

Get production batch repository

pub fn supplier_skus(&self) -> SqliteSupplierSkuRepository

Get supplier SKU repository

pub fn fixed_assets(&self) -> SqliteFixedAssetRepository

Get fixed asset repository

pub fn revenue_recognition(&self) -> SqliteRevenueRecognitionRepository

Get revenue recognition repository

pub fn vendor_returns(&self) -> SqliteVendorReturnRepository

Get vendor return repository

pub fn vendor_credits(&self) -> SqliteVendorCreditRepository

Get vendor credit repository

pub fn payment_obligations(&self) -> SqlitePaymentObligationRepository

Get payment obligation repository

pub fn price_levels(&self) -> SqlitePriceLevelRepository

Get price level repository

pub fn prepayments(&self) -> SqlitePrepaymentRepository

Get prepayment repository

pub fn price_schedules(&self) -> SqlitePriceScheduleRepository

Get price schedule repository

pub fn http_idempotency(&self) -> SqliteHttpIdempotencyRepository

Get the durable HTTP idempotency repository

pub fn activity_logs(&self) -> SqliteActivityLogRepository

Get activity log repository

pub fn integration_mappings(&self) -> SqliteIntegrationMappingRepository

Get integration mapping repository

pub fn inbound_shipments(&self) -> SqliteInboundShipmentRepository

Get inbound shipment repository

pub fn purgatory(&self) -> SqlitePurgatoryRepository

Get purgatory (order ingestion staging) repository

pub fn print_stations(&self) -> SqlitePrintStationRepository

Get print station repository

pub fn edi_documents(&self) -> SqliteEdiDocumentRepository

Get EDI document repository

pub fn integration_field_mappings( &self, ) -> SqliteIntegrationFieldMappingRepository

Get integration field-mapping repository

pub fn topology_snapshots(&self) -> SqliteTopologySnapshotRepository

Get topology snapshot repository

pub fn stock_snapshots(&self) -> SqliteStockSnapshotRepository

Get stock snapshot repository

pub fn zone_shipping_methods(&self) -> SqliteZoneShippingMethodRepository

Get zone shipping method repository

pub fn reviews(&self) -> SqliteReviewRepository

Get product review repository

pub fn wishlists(&self) -> SqliteWishlistRepository

Get wishlist repository

pub fn loyalty_programs(&self) -> SqliteLoyaltyProgramRepository

Get loyalty program repository

pub fn rewards(&self) -> SqliteRewardRepository

Get reward catalog repository

pub fn fraud(&self) -> SqliteFraudRepository

Get fraud detection repository

pub fn search_configs(&self) -> SqliteSearchConfigRepository

Get search configuration repository

pub const fn pool(&self) -> &Pool<SqliteConnectionManager>

Get underlying pool (for advanced use)