pub struct SqliteDatabase { /* private fields */ }sqlite only.Expand description
SQLite database connection pool
Implementations
Sourceimpl SqliteDatabase
impl SqliteDatabase
Sourcepub fn new(config: &DatabaseConfig) -> Result<Self, CommerceError>
pub fn new(config: &DatabaseConfig) -> Result<Self, CommerceError>
Create a new SQLite database connection
Sourcepub fn in_memory() -> Result<Self, CommerceError>
pub fn in_memory() -> Result<Self, CommerceError>
Create an in-memory database (useful for testing)
Sourcepub fn conn(
&self,
) -> Result<PooledConnection<SqliteConnectionManager>, CommerceError>
pub fn conn( &self, ) -> Result<PooledConnection<SqliteConnectionManager>, CommerceError>
Get a connection from the pool
Sourcepub fn health_check(&self) -> Result<DbHealthStatus, CommerceError>
pub fn health_check(&self) -> Result<DbHealthStatus, CommerceError>
Run a health check: verify DB connectivity, return pool and storage stats.
Sourcepub fn shutdown(&self) -> Result<(), CommerceError>
pub fn shutdown(&self) -> Result<(), CommerceError>
Graceful shutdown: checkpoint WAL and optimize before closing.
Call this before dropping the database to ensure all WAL data is flushed to the main database file. Safe to call multiple times.
Sourcepub fn orders(&self) -> SqliteOrderRepository
pub fn orders(&self) -> SqliteOrderRepository
Get order repository
Sourcepub fn inventory(&self) -> SqliteInventoryRepository
pub fn inventory(&self) -> SqliteInventoryRepository
Get inventory repository
Sourcepub fn customers(&self) -> SqliteCustomerRepository
pub fn customers(&self) -> SqliteCustomerRepository
Get customer repository
Sourcepub fn products(&self) -> SqliteProductRepository
pub fn products(&self) -> SqliteProductRepository
Get product repository
Sourcepub fn custom_objects(&self) -> SqliteCustomObjectRepository
pub fn custom_objects(&self) -> SqliteCustomObjectRepository
Get custom objects repository (custom states / metaobjects)
Sourcepub fn returns(&self) -> SqliteReturnRepository
pub fn returns(&self) -> SqliteReturnRepository
Get return repository
Sourcepub fn bom(&self) -> SqliteBomRepository
pub fn bom(&self) -> SqliteBomRepository
Get BOM (Bill of Materials) repository
Sourcepub fn work_orders(&self) -> SqliteWorkOrderRepository
pub fn work_orders(&self) -> SqliteWorkOrderRepository
Get work order repository
Sourcepub fn shipments(&self) -> SqliteShipmentRepository
pub fn shipments(&self) -> SqliteShipmentRepository
Get shipment repository
Sourcepub fn payments(&self) -> SqlitePaymentRepository
pub fn payments(&self) -> SqlitePaymentRepository
Get payment repository
Sourcepub fn warranties(&self) -> SqliteWarrantyRepository
pub fn warranties(&self) -> SqliteWarrantyRepository
Get warranty repository
Sourcepub fn purchase_orders(&self) -> SqlitePurchaseOrderRepository
pub fn purchase_orders(&self) -> SqlitePurchaseOrderRepository
Get purchase order repository
Sourcepub fn invoices(&self) -> SqliteInvoiceRepository
pub fn invoices(&self) -> SqliteInvoiceRepository
Get invoice repository
Sourcepub fn carts(&self) -> SqliteCartRepository
pub fn carts(&self) -> SqliteCartRepository
Get cart repository
Sourcepub fn analytics(&self) -> SqliteAnalyticsRepository
pub fn analytics(&self) -> SqliteAnalyticsRepository
Get analytics repository
Sourcepub fn currency(&self) -> SqliteCurrencyRepository
pub fn currency(&self) -> SqliteCurrencyRepository
Get currency repository
Sourcepub fn tax(&self) -> SqliteTaxRepository
pub fn tax(&self) -> SqliteTaxRepository
Get tax repository
Sourcepub fn promotions(&self) -> SqlitePromotionRepository
pub fn promotions(&self) -> SqlitePromotionRepository
Get promotions repository
Sourcepub fn subscriptions(&self) -> SqliteSubscriptionRepository
pub fn subscriptions(&self) -> SqliteSubscriptionRepository
Get subscriptions repository
Sourcepub fn quality(&self) -> SqliteQualityRepository
pub fn quality(&self) -> SqliteQualityRepository
Get quality repository
Sourcepub fn lots(&self) -> SqliteLotRepository
pub fn lots(&self) -> SqliteLotRepository
Get lots repository
Sourcepub fn serials(&self) -> SqliteSerialRepository
pub fn serials(&self) -> SqliteSerialRepository
Get serials repository
Sourcepub fn warehouse(&self) -> SqliteWarehouseRepository
pub fn warehouse(&self) -> SqliteWarehouseRepository
Get warehouse repository
Sourcepub fn receiving(&self) -> SqliteReceivingRepository
pub fn receiving(&self) -> SqliteReceivingRepository
Get receiving repository
Sourcepub fn fulfillment(&self) -> SqliteFulfillmentRepository
pub fn fulfillment(&self) -> SqliteFulfillmentRepository
Get fulfillment repository
Sourcepub fn accounts_payable(&self) -> SqliteAccountsPayableRepository
pub fn accounts_payable(&self) -> SqliteAccountsPayableRepository
Get accounts payable repository
Sourcepub fn cost_accounting(&self) -> SqliteCostAccountingRepository
pub fn cost_accounting(&self) -> SqliteCostAccountingRepository
Get cost accounting repository
Sourcepub fn credit(&self) -> SqliteCreditRepository
pub fn credit(&self) -> SqliteCreditRepository
Get credit repository
Sourcepub fn backorder(&self) -> SqliteBackorderRepository
pub fn backorder(&self) -> SqliteBackorderRepository
Get backorder repository
Sourcepub fn accounts_receivable(&self) -> SqliteAccountsReceivableRepository
pub fn accounts_receivable(&self) -> SqliteAccountsReceivableRepository
Get accounts receivable repository
Sourcepub fn general_ledger(&self) -> SqliteGeneralLedgerRepository
pub fn general_ledger(&self) -> SqliteGeneralLedgerRepository
Get general ledger repository
Sourcepub fn x402_payment_intents(&self) -> SqliteX402PaymentIntentRepository
pub fn x402_payment_intents(&self) -> SqliteX402PaymentIntentRepository
Get x402 payment intent repository
Sourcepub fn x402_credits(&self) -> SqliteX402CreditRepository
pub fn x402_credits(&self) -> SqliteX402CreditRepository
Get x402 credit ledger repository
Sourcepub fn a2a_quotes(&self) -> SqliteA2ARepository
pub fn a2a_quotes(&self) -> SqliteA2ARepository
Get A2A quote/purchase repository
Sourcepub fn a2a_purchases(&self) -> SqliteA2ARepository
pub fn a2a_purchases(&self) -> SqliteA2ARepository
Get A2A quote/purchase repository
Sourcepub fn agent_cards(&self) -> SqliteAgentCardRepository
pub fn agent_cards(&self) -> SqliteAgentCardRepository
Get agent card repository
Sourcepub fn agent_identities(&self) -> SqliteAgentIdentityRepository
pub fn agent_identities(&self) -> SqliteAgentIdentityRepository
Get agent identity repository (ERC-8004)
Sourcepub fn agent_reputation(&self) -> SqliteAgentReputationRepository
pub fn agent_reputation(&self) -> SqliteAgentReputationRepository
Get agent reputation repository (ERC-8004)
Sourcepub fn agent_validation(&self) -> SqliteAgentValidationRepository
pub fn agent_validation(&self) -> SqliteAgentValidationRepository
Get agent validation repository (ERC-8004)
Sourcepub fn gift_cards(&self) -> SqliteGiftCardRepository
pub fn gift_cards(&self) -> SqliteGiftCardRepository
Get gift card repository
Sourcepub fn store_credits(&self) -> SqliteStoreCreditRepository
pub fn store_credits(&self) -> SqliteStoreCreditRepository
Get store credit repository
Sourcepub fn segments(&self) -> SqliteSegmentRepository
pub fn segments(&self) -> SqliteSegmentRepository
Get customer segment repository
Sourcepub fn shipping_zones(&self) -> SqliteShippingZoneRepository
pub fn shipping_zones(&self) -> SqliteShippingZoneRepository
Get shipping zone repository
Sourcepub fn channels(&self) -> SqliteChannelRepository
pub fn channels(&self) -> SqliteChannelRepository
Get channel repository
Sourcepub fn companies(&self) -> SqliteCompanyRepository
pub fn companies(&self) -> SqliteCompanyRepository
Get company (B2B account) repository
Sourcepub fn transfer_orders(&self) -> SqliteTransferOrderRepository
pub fn transfer_orders(&self) -> SqliteTransferOrderRepository
Get transfer order repository
Sourcepub fn units_of_measure(&self) -> SqliteUnitOfMeasureRepository
pub fn units_of_measure(&self) -> SqliteUnitOfMeasureRepository
Get units-of-measure repository
Sourcepub fn production_batches(&self) -> SqliteProductionBatchRepository
pub fn production_batches(&self) -> SqliteProductionBatchRepository
Get production batch repository
Sourcepub fn supplier_skus(&self) -> SqliteSupplierSkuRepository
pub fn supplier_skus(&self) -> SqliteSupplierSkuRepository
Get supplier SKU repository
Sourcepub fn fixed_assets(&self) -> SqliteFixedAssetRepository
pub fn fixed_assets(&self) -> SqliteFixedAssetRepository
Get fixed asset repository
Sourcepub fn revenue_recognition(&self) -> SqliteRevenueRecognitionRepository
pub fn revenue_recognition(&self) -> SqliteRevenueRecognitionRepository
Get revenue recognition repository
Sourcepub fn vendor_returns(&self) -> SqliteVendorReturnRepository
pub fn vendor_returns(&self) -> SqliteVendorReturnRepository
Get vendor return repository
Sourcepub fn vendor_credits(&self) -> SqliteVendorCreditRepository
pub fn vendor_credits(&self) -> SqliteVendorCreditRepository
Get vendor credit repository
Sourcepub fn payment_obligations(&self) -> SqlitePaymentObligationRepository
pub fn payment_obligations(&self) -> SqlitePaymentObligationRepository
Get payment obligation repository
Sourcepub fn price_levels(&self) -> SqlitePriceLevelRepository
pub fn price_levels(&self) -> SqlitePriceLevelRepository
Get price level repository
Sourcepub fn prepayments(&self) -> SqlitePrepaymentRepository
pub fn prepayments(&self) -> SqlitePrepaymentRepository
Get prepayment repository
Sourcepub fn price_schedules(&self) -> SqlitePriceScheduleRepository
pub fn price_schedules(&self) -> SqlitePriceScheduleRepository
Get price schedule repository
Sourcepub fn http_idempotency(&self) -> SqliteHttpIdempotencyRepository
pub fn http_idempotency(&self) -> SqliteHttpIdempotencyRepository
Get the durable HTTP idempotency repository
Sourcepub fn activity_logs(&self) -> SqliteActivityLogRepository
pub fn activity_logs(&self) -> SqliteActivityLogRepository
Get activity log repository
Sourcepub fn integration_mappings(&self) -> SqliteIntegrationMappingRepository
pub fn integration_mappings(&self) -> SqliteIntegrationMappingRepository
Get integration mapping repository
Sourcepub fn inbound_shipments(&self) -> SqliteInboundShipmentRepository
pub fn inbound_shipments(&self) -> SqliteInboundShipmentRepository
Get inbound shipment repository
Sourcepub fn purgatory(&self) -> SqlitePurgatoryRepository
pub fn purgatory(&self) -> SqlitePurgatoryRepository
Get purgatory (order ingestion staging) repository
Sourcepub fn print_stations(&self) -> SqlitePrintStationRepository
pub fn print_stations(&self) -> SqlitePrintStationRepository
Get print station repository
Sourcepub fn edi_documents(&self) -> SqliteEdiDocumentRepository
pub fn edi_documents(&self) -> SqliteEdiDocumentRepository
Get EDI document repository
Sourcepub fn integration_field_mappings(
&self,
) -> SqliteIntegrationFieldMappingRepository
pub fn integration_field_mappings( &self, ) -> SqliteIntegrationFieldMappingRepository
Get integration field-mapping repository
Sourcepub fn topology_snapshots(&self) -> SqliteTopologySnapshotRepository
pub fn topology_snapshots(&self) -> SqliteTopologySnapshotRepository
Get topology snapshot repository
Sourcepub fn stock_snapshots(&self) -> SqliteStockSnapshotRepository
pub fn stock_snapshots(&self) -> SqliteStockSnapshotRepository
Get stock snapshot repository
Sourcepub fn zone_shipping_methods(&self) -> SqliteZoneShippingMethodRepository
pub fn zone_shipping_methods(&self) -> SqliteZoneShippingMethodRepository
Get zone shipping method repository
Sourcepub fn reviews(&self) -> SqliteReviewRepository
pub fn reviews(&self) -> SqliteReviewRepository
Get product review repository
Sourcepub fn wishlists(&self) -> SqliteWishlistRepository
pub fn wishlists(&self) -> SqliteWishlistRepository
Get wishlist repository
Sourcepub fn loyalty_programs(&self) -> SqliteLoyaltyProgramRepository
pub fn loyalty_programs(&self) -> SqliteLoyaltyProgramRepository
Get loyalty program repository
Sourcepub fn rewards(&self) -> SqliteRewardRepository
pub fn rewards(&self) -> SqliteRewardRepository
Get reward catalog repository
Sourcepub fn fraud(&self) -> SqliteFraudRepository
pub fn fraud(&self) -> SqliteFraudRepository
Get fraud detection repository
Sourcepub fn search_configs(&self) -> SqliteSearchConfigRepository
pub fn search_configs(&self) -> SqliteSearchConfigRepository
Get search configuration repository
Sourcepub const fn pool(&self) -> &Pool<SqliteConnectionManager>
pub const fn pool(&self) -> &Pool<SqliteConnectionManager>
Get underlying pool (for advanced use)